/**
 * Compare two arrays of objects, to get the created, updated, and deleted values
 * @param {Array.<Object>} toCompareVals The first array item must be the original array of objects.
 * [originalArray, stateUpdatedArray]
 * @param {?string|Array.<string>} key The related key between the objects
 * @returns {{createdVals: ?Array.<Object>, updatedVals: ?Array.<Object>, deletedVals: ?Array.<Object>, sameVals: ?Array.<Object>}}
 * An object with the corresponding created, updated, and deleted properties and values.
 * Returns null for one of the corresponding values if it doesn't exist.
 */
declare function compareObjectVals(toCompareVals: [Object[], Object[]], key?: string | string[]): {
    createdVals: Object[] | null;
    updatedVals: Object[] | null;
    deletedVals: Object[] | null;
    sameVals: Object[] | null;
};
/**
 * Compare two arrays, to get the created & deleted values
 * @param {Array.<Array.<*>, Array.<*>>} toCompareVals The first array item must be the original array!
 * [originalArray, stateUpdatedArray]
 * @returns {{ createdVals: ?Array.<*>, deletedVals: ?Array.<*> }}
 * Returns two arrays corresponding to the created and deleted values
 * respectively. Returns null for one of the corresponding values if it doesn't exist.
 */
declare function compareArrayVals(toCompareVals: [any[], any[]]): {
    createdVals: any[] | null;
    deletedVals: any[] | null;
    sameVals: any[] | null;
};
export { compareObjectVals, compareArrayVals };
//# sourceMappingURL=main.d.ts.map